@@ -51,7 +51,10 @@ from wechaty_puppet import (  # type: ignore
     EventRoomJoinPayload,
 
     ScanStatus,
-    EventReadyPayload)
+    EventReadyPayload,
+
+    get_logger
+)
 from wechaty_puppet.schemas.puppet import PUPPET_EVENT_DICT, PuppetOptions  # type: ignore
 from wechaty_puppet.state_switch import StateSwitch     # type: ignore
 from wechaty_puppet.watch_dog import WatchdogFood, Watchdog     # type: ignore
@@ -67,9 +70,6 @@ from .user import (
 from .utils import (
     qr_terminal
 )
-from .config import (
-    get_logger,
-)
 
 log = get_logger('Wechaty')
 
@@ -136,7 +136,7 @@ class Wechaty(AsyncIOEventEmitter):
     def _load_puppet(options: WechatyOptions) -> Puppet:
         """
         dynamic load puppet
-        :param puppet_options:
+        :param options:
         :return:
         """
         if options.puppet is None:
@@ -354,7 +354,7 @@ class Wechaty(AsyncIOEventEmitter):
         """
         init puppet event stream
         """
-        log.info('init_puppet_event_brideg() <%s>', puppet)
+        log.info('init_puppet_event_bridge() <%s>', puppet)
         event_names = PUPPET_EVENT_DICT.keys()
         for event_name in event_names:
             if event_name == 'dong':
@@ -387,9 +387,9 @@ class Wechaty(AsyncIOEventEmitter):
                     log.info('receive <friendship> event <%s>', payload)
                     friendship = self.Friendship.load(payload.friendship_id)
                     await friendship.ready()
-                    self.emit('friendship', payload)
+                    self.emit('friendship', friendship)
                     friendship.contact().emit('friendship', friendship)
-                    await self.on_friendship(payload)
+                    await self.on_friendship(friendship)
 
                 puppet.on('friendship', friendship_listener)
 
